MasterOptions

Struct MasterOptions 

pub struct MasterOptions {
    pub master: Option<String>,
    pub domain: Option<String>,
    pub token: Option<String>,
}
Options for master-pass mode.

Fields

master: Option<String>

Set the master passphrase to use for generating passwords.

In master passphrase mode, Passgen uses the master passphrase you supply here to generate deterministic outputs. With this functionality, you can use Passgen as a password manager, only having to remember a single master passphrase and using it to generate unique passphrases per domain and login.

This also enables the master-passphrase randomness source. You cannot combine this with any other randomness source.

domain: Option<String>

Set the domain for the master passphrase mode.

Requires that you specify a master passphrase.

token: Option<String>

Set the token for the master passphrase.

This allows you to generate multiple, unique passphrases for a single domain, for example if you have multiple accounts.

Implementations