pub struct Options {
pub preset: Option<String>,
pub amount: usize,
pub random: Option<Random>,
pub master: MasterOptions,
pub format: Format,
pub threads: Option<usize>,
pub verbose: Option<usize>,
pub wordlist: Vec<WordlistSpec>,
pub pattern: Option<String>,
pub config: Vec<PathBuf>,
}Expand description
Generate random sequences from a regex-like pattern.
Fields
preset: Option<String>Use the given named preset instead of specifying a pattern.
amount: usizeAmount of sequences to generate.
random: Option<Random>Source of randomness to use.
Possible sources are:
system: use the secure system random number generator (default)
null: use a dummy randomness source (insecure)
xoshiro:<seed>: use the xoshiro randomness source with the given seed (insecure)
master: MasterOptionsformat: FormatOutput format to use when emitting generated sequences.
This defaults to a text-based format, but you can also specify ‘json’ or ‘csv’.
threads: Option<usize>Amount of threads to use, enables multi-threaded generation.
verbose: Option<usize>Enable debug log output.
wordlist: Vec<WordlistSpec>Load wordlist for generating wordlist or markov-chain based words.
The format of this is <name>:<path>. For example, to load a wordlist with the name
english that is located at /usr/share/dict/words, specify -w english:/usr/share/dict/words.
pattern: Option<String>config: Vec<PathBuf>Load configuration file.
Implementations